



if not exist %LIBRARY_INC%\mysql\mysql.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\mysql\mysqlx_version.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\mysqlclient.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
